====================
django Standard Form
====================

Quick and simple django templatetags for displaying forms.


Installation
============

1) ``pip install django-standard-form``

2) add ``'standard_form'`` to your ``INSTALLED_APPS``

